@@ -35,7 +35,7 @@
 #include "pixmapfx/kpPixmapFX.h"
 
 #include "kpLogCategories.h"
-#include <klocale.h>
+#include <KLocalizedString>
 #include <knuminput.h>
 
 #include <cmath>
